@@ -365,19 +365,17 @@ TODO
 from collections import defaultdict
 from weakref import WeakKeyDictionary
 
-import sqlalchemy as sa
 import six
+import sqlalchemy as sa
 from sqlalchemy.ext.declarative import declared_attr
-try:
-    # SQLAlchemy 0.9
-    from sqlalchemy.sql.functions import _FunctionGenerator
-except ImportError:
-    # SQLAlchemy 0.8
-    from sqlalchemy.sql.expression import _FunctionGenerator
+from sqlalchemy.sql.functions import _FunctionGenerator
 
 from .functions.orm import get_column_key
-from .relationships import chained_join, select_aggregate
-
+from .relationships import (
+    chained_join,
+    path_to_relationships,
+    select_correlated_expression
+)
 
 aggregated_attrs = WeakKeyDictionary(defaultdict(list))
 
@@ -437,17 +435,25 @@ def aggregate_expression(expr, class_):
 
 
 class AggregatedValue(object):
-    def __init__(self, class_, attr, relationships, expr):
+    def __init__(self, class_, attr, path, expr):
         self.class_ = class_
         self.attr = attr
-        self.relationships = relationships
+        self.path = path
+        self.relationships = list(
+            reversed(path_to_relationships(path, class_))
+        )
         self.expr = aggregate_expression(expr, class_)
 
     @property
     def aggregate_query(self):
-        query = select_aggregate(self.expr, self.relationships)
+        query = select_correlated_expression(
+            self.class_,
+            self.expr,
+            self.path,
+            self.relationships[0].mapper.class_
+        )
 
-        return query.correlate(self.class_).as_scalar()
+        return query.as_scalar()
 
     def update_query(self, objects):
         table = self.class_.__table__
@@ -514,22 +520,16 @@ class AggregationManager(object):
 
     def update_generator_registry(self):
         for class_, attrs in six.iteritems(aggregated_attrs):
-            for expr, relationship, column in attrs:
-                relationships = []
-                rel_class = class_
-
-                for path_name in relationship.split('.'):
-                    rel = getattr(rel_class, path_name)
-                    relationships.append(rel)
-                    rel_class = rel.mapper.class_
-
-                self.generator_registry[rel_class].append(
-                    AggregatedValue(
-                        class_=class_,
-                        attr=column,
-                        relationships=list(reversed(relationships)),
-                        expr=expr(class_)
-                    )
+            for expr, path, column in attrs:
+                value = AggregatedValue(
+                    class_=class_,
+                    attr=column,
+                    path=path,
+                    expr=expr(class_)
+                )
+                key = value.relationships[0].mapper.class_
+                self.generator_registry[key].append(
+                    value
                 )
 
     def construct_aggregate_queries(self, session, ctx):
