@@ -9,11 +9,12 @@ from operator import attrgetter
 
 import six
 import sqlalchemy as sa
+from sqlalchemy.engine.interfaces import Dialect
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import mapperlib
 from sqlalchemy.orm.attributes import InstrumentedAttribute
 from sqlalchemy.orm.exc import UnmappedInstanceError
-from sqlalchemy.orm.properties import ColumnProperty
+from sqlalchemy.orm.properties import ColumnProperty, RelationshipProperty
 from sqlalchemy.orm.query import _ColumnEntity
 from sqlalchemy.orm.session import object_session
 from sqlalchemy.orm.util import AliasedInsp
@@ -104,6 +105,54 @@ def get_class_by_table(base, table, data=None):
     return None
 
 
+def get_type(expr):
+    """
+    Return the associated type with given Column, InstrumentedAttribute,
+    ColumnProperty, RelationshipProperty or other similar SQLAlchemy construct.
+
+    For constructs wrapping columns this is the column type. For relationships
+    this function returns the relationship mapper class.
+
+    :param expr:
+        SQLAlchemy Column, InstrumentedAttribute, ColumnProperty or other
+        similar SA construct.
+
+    ::
+
+        class User(Base):
+            __tablename__ = 'user'
+            id = sa.Column(sa.Integer, primary_key=True)
+            name = sa.Column(sa.String)
+
+
+        class Article(Base):
+            __tablename__ = 'article'
+            id = sa.Column(sa.Integer, primary_key=True)
+            author_id = sa.Column(sa.Integer, sa.ForeignKey(User.id))
+            author = sa.orm.relationship(User)
+
+
+        get_type(User.__table__.c.name)  # sa.String()
+        get_type(User.name)  # sa.String()
+        get_type(User.name.property)  # sa.String()
+
+        get_type(Article.author)  # User
+
+
+    .. versionadded: 0.30.9
+    """
+    if hasattr(expr, 'type'):
+        return expr.type
+    elif isinstance(expr, InstrumentedAttribute):
+        expr = expr.property
+
+    if isinstance(expr, ColumnProperty):
+        return expr.columns[0].type
+    elif isinstance(expr, RelationshipProperty):
+        return expr.mapper.class_
+    raise TypeError("Couldn't inspect type.")
+
+
 def get_column_key(model, column):
     """
     Return the key for given column in given model.
@@ -354,14 +403,18 @@ def get_columns(mixed):
         SA Table object, SA Mapper, SA declarative class, SA declarative class
         instance or an alias of any of these objects
     """
-    if isinstance(mixed, sa.Table):
+    if isinstance(mixed, sa.sql.selectable.Selectable):
         return mixed.c
     if isinstance(mixed, sa.orm.util.AliasedClass):
         return sa.inspect(mixed).mapper.columns
-    if isinstance(mixed, sa.sql.selectable.Alias):
-        return mixed.c
     if isinstance(mixed, sa.orm.Mapper):
         return mixed.columns
+    if isinstance(mixed, InstrumentedAttribute):
+        return mixed.property.columns
+    if isinstance(mixed, ColumnProperty):
+        return mixed.columns
+    if isinstance(mixed, sa.Column):
+        return [mixed]
     if not isclass(mixed):
         mixed = mixed.__class__
     return sa.inspect(mixed).columns
@@ -407,10 +460,13 @@ def quote(mixed, ident):
         # 'some_other_identifier'
 
 
-    :param mixed: SQLAlchemy Session / Connection / Engine object.
+    :param mixed: SQLAlchemy Session / Connection / Engine / Dialect object.
     :param ident: identifier to conditionally quote
     """
-    dialect = get_bind(mixed).dialect
+    if isinstance(mixed, Dialect):
+        dialect = mixed
+    else:
+        dialect = get_bind(mixed).dialect
     return dialect.preparer(dialect).quote(ident)
 
 
@@ -572,16 +628,20 @@ def get_descriptor(entity, attr):
 
 
 def get_all_descriptors(expr):
+    if isinstance(expr, sa.sql.selectable.Selectable):
+        return expr.c
     insp = sa.inspect(expr)
-    polymorphic_mappers = get_polymorphic_mappers(insp)
-    if polymorphic_mappers:
+    try:
+        polymorphic_mappers = get_polymorphic_mappers(insp)
+    except sa.exc.NoInspectionAvailable:
+        return get_mapper(expr).all_orm_descriptors
+    else:
         attrs = dict(get_mapper(expr).all_orm_descriptors)
         for submapper in polymorphic_mappers:
             for key, descriptor in submapper.all_orm_descriptors.items():
                 if key not in attrs:
                     attrs[key] = descriptor
         return attrs
-    return get_mapper(expr).all_orm_descriptors
 
 
 def get_hybrid_properties(model):
