@@ -1,11 +1,14 @@
 import sqlalchemy as sa
+from sqlalchemy.ext.declarative import declarative_base
+
 from sqlalchemy_utils import get_columns
-from tests import TestCase
 
 
-class TestGetColumns(TestCase):
-    def create_models(self):
-        class Building(self.Base):
+class TestGetColumns(object):
+    def setup_method(self, method):
+        Base = declarative_base()
+
+        class Building(Base):
             __tablename__ = 'building'
             id = sa.Column('_id', sa.Integer, primary_key=True)
             name = sa.Column('_name', sa.Unicode(255))
@@ -18,6 +21,19 @@ class TestGetColumns(TestCase):
             sa.sql.base.ImmutableColumnCollection
         )
 
+    def test_instrumented_attribute(self):
+        assert get_columns(self.Building.id) == [self.Building.__table__.c._id]
+
+    def test_column_property(self):
+        assert get_columns(self.Building.id.property) == [
+            self.Building.__table__.c._id
+        ]
+
+    def test_column(self):
+        assert get_columns(self.Building.__table__.c._id) == [
+            self.Building.__table__.c._id
+        ]
+
     def test_declarative_class(self):
         assert isinstance(
             get_columns(self.Building),
